pub struct AddGroupsToGroupV1InstructionArgs {
pub groups: Vec<Pubkey>,
}Fields
groups: Vec<Pubkey>Trait Implementations
Sourceimpl BorshDeserialize for AddGroupsToGroupV1InstructionArgs
impl BorshDeserialize for AddGroupsToGroupV1InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AddGroupsToGroupV1InstructionArgs
impl Clone for AddGroupsToGroupV1InstructionArgs
Sourcefn clone(&self) -> AddGroupsToGroupV1InstructionArgs
fn clone(&self) -> AddGroupsToGroupV1InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AddGroupsToGroupV1InstructionArgs
impl PartialEq for AddGroupsToGroupV1InstructionArgs
Sourcefn eq(&self, other: &AddGroupsToGroupV1InstructionArgs) -> bool
fn eq(&self, other: &AddGroupsToGroupV1InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AddGroupsToGroupV1InstructionArgs
impl StructuralPartialEq for AddGroupsToGroupV1InstructionArgs