pub struct CreateGroupV1InstructionArgs {
pub name: String,
pub uri: String,
pub relationships: Vec<RelationshipEntry>,
}Fields
name: Stringuri: Stringrelationships: Vec<RelationshipEntry>Trait Implementations
Sourceimpl BorshDeserialize for CreateGroupV1InstructionArgs
impl BorshDeserialize for CreateGroupV1InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateGroupV1InstructionArgs
impl Clone for CreateGroupV1InstructionArgs
Sourcefn clone(&self) -> CreateGroupV1InstructionArgs
fn clone(&self) -> CreateGroupV1InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateGroupV1InstructionArgs
impl Debug for CreateGroupV1InstructionArgs
Sourceimpl PartialEq for CreateGroupV1InstructionArgs
impl PartialEq for CreateGroupV1InstructionArgs
Sourcefn eq(&self, other: &CreateGroupV1InstructionArgs) -> bool
fn eq(&self, other: &CreateGroupV1InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateGroupV1InstructionArgs
impl StructuralPartialEq for CreateGroupV1InstructionArgs