pub struct UpdateCollectionExternalPluginAdapterV1InstructionArgs {
pub key: ExternalPluginAdapterKey,
pub update_info: ExternalPluginAdapterUpdateInfo,
}Fields
key: ExternalPluginAdapterKeyupdate_info: ExternalPluginAdapterUpdateInfoTrait Implementations
sourceimpl BorshDeserialize for UpdateCollectionExternalPluginAdapterV1InstructionArgs
impl BorshDeserialize for UpdateCollectionExternalPluginAdapterV1InstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl Clone for UpdateCollectionExternalPluginAdapterV1InstructionArgs
impl Clone for UpdateCollectionExternalPluginAdapterV1InstructionArgs
sourcefn clone(&self) -> UpdateCollectionExternalPluginAdapterV1InstructionArgs
fn clone(&self) -> UpdateCollectionExternalPluginAdapterV1InstructionArgs
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl PartialEq for UpdateCollectionExternalPluginAdapterV1InstructionArgs
impl PartialEq for UpdateCollectionExternalPluginAdapterV1InstructionArgs
sourcefn eq(
&self,
other: &UpdateCollectionExternalPluginAdapterV1InstructionArgs
) -> bool
fn eq( &self, other: &UpdateCollectionExternalPluginAdapterV1InstructionArgs ) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for UpdateCollectionExternalPluginAdapterV1InstructionArgs
impl StructuralPartialEq for UpdateCollectionExternalPluginAdapterV1InstructionArgs