pub struct UpdateGroupV1InstructionArgs {
pub new_name: Option<String>,
pub new_uri: Option<String>,
}Fields
new_name: Option<String>new_uri: Option<String>Trait Implementations
Sourceimpl BorshDeserialize for UpdateGroupV1InstructionArgs
impl BorshDeserialize for UpdateGroupV1InstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateGroupV1InstructionArgs
impl Clone for UpdateGroupV1InstructionArgs
Sourcefn clone(&self) -> UpdateGroupV1InstructionArgs
fn clone(&self) -> UpdateGroupV1InstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateGroupV1InstructionArgs
impl Debug for UpdateGroupV1InstructionArgs
Sourceimpl PartialEq for UpdateGroupV1InstructionArgs
impl PartialEq for UpdateGroupV1InstructionArgs
Sourcefn eq(&self, other: &UpdateGroupV1InstructionArgs) -> bool
fn eq(&self, other: &UpdateGroupV1InstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateGroupV1InstructionArgs
impl StructuralPartialEq for UpdateGroupV1InstructionArgs