ExternalRegistryRecordSafe

Struct ExternalRegistryRecordSafe 

pub struct ExternalRegistryRecordSafe {
    pub plugin_type: u8,
    pub authority: PluginAuthority,
    pub lifecycle_checks: Option<Vec<(u8, ExternalCheckResult)>>,
    pub offset: u64,
    pub data_offset: Option<u64>,
    pub data_len: Option<u64>,
}
ExternalPluginAdapter Registry record that can be used when the plugin type is not known (i.e. a ExternalPluginAdapterType that is too new for this client to know about).

Fields

plugin_type: u8authority: PluginAuthoritylifecycle_checks: Option<Vec<(u8, ExternalCheckResult)>>offset: u64data_offset: Option<u64>data_len: Option<u64>

Implementations

Source

impl ExternalRegistryRecordSafe

pub fn compare_offsets( a: &ExternalRegistryRecordSafe, b: &ExternalRegistryRecordSafe, ) -> Ordering

Associated function for sorting RegistryRecordIndexable by offset.