IndexableAsset

Struct IndexableAsset 

pub struct IndexableAsset {
    pub owner: Option<Pubkey>,
    pub update_authority: UpdateAuthority,
    pub name: String,
    pub uri: String,
    pub seq: u64,
    pub num_minted: Option<u32>,
    pub current_size: Option<u32>,
    pub plugins: HashMap<PluginType, IndexablePluginSchemaV1>,
    pub unknown_plugins: Vec<IndexableUnknownPluginSchemaV1>,
    pub external_plugins: Vec<IndexableExternalPluginSchemaV1>,
    pub unknown_external_plugins: Vec<IndexableUnknownExternalPluginSchemaV1>,
}
A type used to store Core Assets, Collections, and Groups for indexing.

Fields

owner: Option<Pubkey>update_authority: UpdateAuthorityname: Stringuri: Stringseq: u64num_minted: Option<u32>current_size: Option<u32>plugins: HashMap<PluginType, IndexablePluginSchemaV1>unknown_plugins: Vec<IndexableUnknownPluginSchemaV1>external_plugins: Vec<IndexableExternalPluginSchemaV1>unknown_external_plugins: Vec<IndexableUnknownExternalPluginSchemaV1>

Implementations

Source

impl IndexableAsset

pub fn from_asset(asset: BaseAssetV1, seq: u64) -> Self

Create a new IndexableAsset from a BaseAssetV1``. Note this uses a passed-in seqrather than the one contained inasset` to avoid errors.

pub fn from_collection(collection: BaseCollectionV1) -> Self

Create a new IndexableAsset from a BaseCollectionV1.

pub fn from_group(group: GroupV1) -> Self

Create a new IndexableAsset from a GroupV1.

pub fn fetch(key: Key, account: &[u8]) -> Result<Self, Error>

Fetch the base Asset, Collection, or Group and all the plugins and store in an IndexableAsset.